/*
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
	Replication file for:
	
	Paper: 	 How Effective Are Social Distancing Policies?
			 Evidence on the Fight Against COVID-19
			 from Germany
			 
	Authors: Ulrich Glogowsky, Emanuel Hansen, Simeon Schächtele
	
	Content: This file replicates the main results. This includes: Figure 1 
			 and Figure 4. The other figures rely data (which we are not allowed
			 to share) 
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
*/

/*
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
	Part 1: globals
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
*/

*** clear
	clear all
	set more off
	
*** globals for linux users
	if "$S_OS" == "Unix"	{	
		global path ""			// insert folder with datasat
		global programs ""		// insert folder with datasat
		global graphs ""		// insert folder in which the results will be stored 
	}
*** globals for windows users
	else {
		global path ""			// insert folder with datasat
		global programs "" 		// insert folder with programs 
		global graphs "" 		// insert folder in which the results will be stored 
	}

/*
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
	Part 2: main regressions
	        outcome: IHS of cumulative number of confirmed cases
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
*/		

*** use data
	use $path/GHS_SDPolicies, clear
	set mat 11000	

*** create directory for graphs
	cap mkdir $graphs/ 
	cap mkdir $graphs/IHSSumCases 

*** set more off
	set more off, perm
			
*** regression
		
	*** locals for estimation and graphs
		local baselevel = d(11march2020) 	// excluded period in regressions
		local theta = 1						// parameter of IHS transformation (1=standard). used to re-transform values
		local cluster = 1					// estimation with clustered SDs. used to name graph
		local start = "14feb2020"			// start: estimation period. used to name graph
		local end = "20apr2020"				// end: estimation period. used to name graph
		local StDate = 10					// number of cases within 2 weeks. used to name graph
												
	*** load program
		do "$programs/program_event.do"
	
	*** estimation									
		event_study, 			        	   													/// 
			outcome(IHSSumCases)																///	// outcome
			event(DateInf)																		///	// time relative to event
			stdate(i.StDate2Weeks`StDate')														///	// time relative to start of pandemic
			baselevel(`baselevel')																///	// reference category in regression			
			covariates()																		///	// further covariates							
			std(vce(cl CountyId))																/// // robust: "r"; clusters ", vce(cl CLUSTER)" 
			level(95)																			/// // confidence level
			graphpath($graphs/IHSSumCases)														/// // folder were graph will be saved
			ytitilegraph1("Cases per district")													/// // y-titile graph 1
			graphname1(TE0_CL`cluster'_District_SStDate2Weeks`StDate'_`start'_`end'_revision)	/// // name of first graph that shows distancing- vs and counterfactual group			
			ytitilegraph2("Avoided cases in Germany (in 1,000s)")								/// // y-titile graph 2
			graphname2(TE1_CL`cluster'_Germany_StDate2Weeks`StDate'_`start'_`end'_revision)		///	// name of second graph that shows distancing effect							
			ytitilegraph4("Change in cases per district")										/// // y-titile graph 3
			graphname4(TE1_CL`cluster'_District_StDate2Weeks`StDate'_`start'_`end'_revision)	///	// name of second graph that shows SDEffect
			theta(`theta')																		///	// theta for IHS re-transformation 
			nosave(0) 																			/// // don't save graph: 0=save; 1=don't save				

/*
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
	Part 3: main regressions
	        outcome: IHS of cumulative number of confirmed fatalities
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
*/		

*** use data
	use $path/GHS_SDPolicies, clear
	set mat 11000	

*** create directory for graphs
	cap mkdir $graphs/ 
	cap mkdir $graphs/IHSSumDeaths 

*** set more off
	set more off, perm
			
*** regression
		
	*** locals for estimation and graphs
		local baselevel = d(11march2020) 	// excluded period in regressions
		local theta = 1						// parameter of IHS transformation (1=standard). used to re-transform values
		local cluster = 1					// estimation with clustered SDs. used to name graph
		local start = "14feb2020"			// start: estimation period. used to name graph
		local end = "20apr2020"				// end: estimation period. used to name graph
		local StDate = 10					// number of cases within 2 weeks. used to name graph
												
	*** load program
		do "$programs/program_event.do"
	
	*** estimation									
		event_study, 			        	   													/// 
			outcome(IHSSumDeaths)																///	// outcome
			event(DateInf)																		///	// time relative to event
			stdate(i.StDate2Weeks`StDate')														///	// time relative to start of pandemic
			baselevel(`baselevel')																///	// reference category in regression			
			covariates()																		///	// further covariates							
			std(vce(cl CountyId))																/// // robust: "r"; clusters ", vce(cl CLUSTER)" 
			level(95)																			/// // confidence level
			graphpath($graphs/IHSSumDeaths)														/// // folder were graph will be saved
			ytitilegraph1("Deaths per district")												/// // y-titile graph 1
			graphname1(TE0_CL`cluster'_District_SStDate2Weeks`StDate'_`start'_`end'_revision)	/// // name of first graph that shows distancing- vs and counterfactual group			
			ytitilegraph2("Avoided deaths in Germany (in 1,000s)")								/// // y-titile graph 2
			graphname2(TE1_CL`cluster'_Germany_StDate2Weeks`StDate'_`start'_`end'_revision)		///	// name of second graph that shows distancing effect							
			ytitilegraph4("Change in deaths per district")										/// // y-titile graph 3
			graphname4(TE1_CL`cluster'_District_StDate2Weeks`StDate'_`start'_`end'_revision)	///	// name of second graph that shows SDEffect
			theta(`theta')																		///	// theta for IHS re-transformation 
			nosave(0) 																			/// // don't save graph: 0=save; 1=don't save			

exit