/*
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
	Replication file for:
	
	Paper: 	 How Effective Are Social Distancing Policies?
			 Evidence on the Fight Against COVID-19
			 from Germany
			 
	Authors: Ulrich Glogowsky, Emanuel Hansen, Simeon Schächtele
	
	Content: This file implements a program for the event-study estimator. 
	         It also produces the graphs.
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
*/
	cap program drop event_study
	program define event_study, eclass
		
		*** Syntax
			syntax [varlist] [if], [          	/// 
				outcome(string)					///
				event(string)					///
				stdate(string)					///
				baselevel(string)				///				
				covariates(string)				///							
				std(string)						///
				level(int 95)					///
				graphpath(string)				///
				graphname1(string)				///
				graphname2(string)				///
				graphname4(string)				///																		
				ytitilegraph1(string)			///
				ytitilegraph2(string)			///
				ytitilegraph4(string)			///	
				theta(real 1)					///																			
				nosave(int 0)]	
	
		*** regression
			reg `outcome' ib`baselevel'.`event' i.`stdate' `covariates', level(`level') `std' 

		*** quite
			qui {
			
		*** regression results
			matrix betas = e(b)	
			local df = e(df_r)	
			local N = e(N)		
			local cilevel =  ((100 - `level') / 2) / 100	

		*** standard error of prediction
			predict double stdp if e(sample), stdp		
		
		*** coefficients of event dummies
			matrix table = r(table)
			qui sum `event'
			local noperiods = r(max) - r(min) + 1			
			matrix b  = table[1, 1..`noperiods']'
			matrix ll = table[5, 1..`noperiods']'
			matrix ul = table[6, 1..`noperiods']'			
		
		*** regression fit
			qui estat ic
			mat IC = r(S)
			scalar AIC = IC[1,5]
			scalar BIC = IC[1,6]
			scalar R2 = e(r2)
			scalar R2a = e(r2_a)
		
		*** prediction: with social distancing
			matrix score double yhat = betas if e(sample)					
			qui gen double yhat_ul = yhat + invttail(`df', `cilevel') * stdp if e(sample)	
			qui gen double yhat_ll = yhat - invttail(`df', `cilevel') * stdp if e(sample)	
			
		*** prediction: without social distancing (set lockdown dummies to zero)
			
			*** local with names of betas
				local names: colnames betas	
					
			*** set event dummies to zero
				foreach name of local names {					
					 if strpos("`name'", "`event'") > 0 {						
						scalar define col_idx = colnumb(betas, "`name'")		
						matrix betas[1, col_idx] = 0							
					 }
				  }   
							
			*** score matrix to generate predictions
				matrix score double yhat2 = betas if e(sample)				
				qui gen double  yhat_ul2 = yhat2 + invttail(`df', `cilevel') * stdp if e(sample)	
				qui gen double  yhat_ll2 = yhat2 - invttail(`df', `cilevel') * stdp if e(sample)		 		

		*** graph: world with versus without sd
			preserve
			
				*** collapse	
					collapse (mean) yhat yhat2 yhat_ll yhat_ul yhat_ll2 yhat_ul2 `outcome', by(`event')	
					
				*** scale
					local linepattern = "shortdash" 
					local lwidth1 = 0.3
					local lwidth2 = 0.3
				
				*** locals with y-axis labels 
					if "`outcome'" == "IHSSumCases" {
						
						*** until 19.4
							local ylabel1 ".881374 "1" 2.9982231 "10" 5.2983432 "100" 7.600903 "1000" 9.903488 "10000""
							local yscale1 "range(0 9.3)"
							local tlabel1 "17feb2020 24feb2020 02mar2020 9mar2020 16mar2020 23mar2020 30mar2020 06apr2020 13apr2020"
						
						*** until 2.4
							local tlabel2 "17feb2020 24feb2020 02mar2020 9mar2020 16mar2020 23mar2020 30mar2020"
							local ylabel2 ".881374 "1" 2.9982231 "10" 5.2983432 "100" 7.600903 "1000" 9.903488 "10000""
											
					}
					if "`outcome'" == "IHSSumDeaths" {
						
						*** until 19.4
							local condition "if `event' > d(25feb2020)"
							local ylabel1 ".881374 "1" 2.9982231 "10" 5.2983432 "100" 6.27 "264""
							local tlabel1 "02mar2020 9mar2020 16mar2020 23mar2020 30mar2020 06apr2020 13apr2020"							
							local condition3 "& `event' > d(25feb2020)"
						
						*** until 2.4
							local tlabel2 "02mar2020 9mar2020 16mar2020 23mar2020 30mar2020"
							local ylabel2 ".881374 "1" 2.9982231 "10""
					}									
						
				*** graph: until 19.4
					if "`outcome'" == "IHSSumCases" {
						gen shade = 11				
						local text = "1.2 22015.5"
					}
					if "`outcome'" == "IHSSumDeaths" {				
						gen shade = 6.5			
						local text = "0.5 22015.5"							
					}
					
					twoway 	(area shade `event' if `event' >= d(02apr2020), color(gray) sort lwidth(none) lcolor(white) fintensity(5))																			///
							///SD group
							(line yhat `event' `condition', sort lcolor(red) mcolor(red) lwidth(`lwidth1')  msize(2))																							///
							(rarea yhat_ll yhat_ul `event' `condition', sort fcolor(red%30) lcolor(red%3))																										///			
							///no SD group	
							(line yhat2 `event' if `event' <= d(02apr2020) `condition3', sort lcolor("106 106 255") mcolor("106 106 255") lwidth(`lwidth1')  msize(2))											///
							(line yhat2 `event' if `event' >= d(02apr2020) & `event' <= d(03apr2020) `condition3', sort lcolor("106 106 255*0.87") mcolor("106 106 255") lwidth(`lwidth1')  msize(2))			///					
							(line yhat2 `event' if `event' >= d(03apr2020) & `event' <= d(04apr2020) `condition3', sort lcolor("106 106 255*0.8") mcolor("106 106 255") lwidth(`lwidth1')  msize(2))			///
							(line yhat2 `event' if `event' >= d(04apr2020) & `event' <= d(05apr2020) `condition3', sort lcolor("106 106 255*0.7") mcolor("106 106 255") lwidth(`lwidth1')  msize(2))			///
							(line yhat2 `event' if `event' >= d(05apr2020) & `event' <= d(06apr2020) `condition3', sort lcolor("106 106 255*0.65") mcolor("106 106 255") lwidth(`lwidth1')  msize(2))			///
							(line yhat2 `event' if `event' >= d(06apr2020) & `event' <= d(07apr2020) `condition3', sort lcolor("106 106 255*0.6") mcolor("106 106 255") lwidth(`lwidth1')  msize(2))			///
							(line yhat2 `event' if `event' >= d(07apr2020) & `event' <= d(08apr2020) `condition3', sort lcolor("106 106 255*0.6") mcolor("106 106 255") lwidth(`lwidth1')  msize(2))			///
							(line yhat2 `event' if `event' >= d(08apr2020) & `event' <= d(09apr2020) `condition3', sort lcolor("106 106 255*0.55") mcolor("106 106 255") lwidth(`lwidth1')  msize(2))			///
							(line yhat2 `event' if `event' >= d(09apr2020) & `event' <= d(10apr2020) `condition3', sort lcolor("106 106 255*0.55") mcolor("106 106 255") lwidth(`lwidth1')  msize(2))			///
							(line yhat2 `event' if `event' >= d(10apr2020) & `event' <= d(11apr2020) `condition3', sort lcolor("106 106 255*0.5") mcolor("106 106 255") lwidth(`lwidth1')  msize(2))			///
							(line yhat2 `event' if `event' >= d(11apr2020) & `event' <= d(12apr2020) `condition3', sort lcolor("106 106 255*0.5") mcolor("106 106 255") lwidth(`lwidth1')  msize(2))			///
							(line yhat2 `event' if `event' >= d(12apr2020) & `event' <= d(13apr2020) `condition3', sort lcolor("106 106 255*0.45") mcolor("106 106 255") lwidth(`lwidth1')  msize(2))			///
							(line yhat2 `event' if `event' >= d(13apr2020) & `event' <= d(14apr2020) `condition3', sort lcolor("106 106 255*0.45") mcolor("106 106 255") lwidth(`lwidth1')  msize(2))			///
							(line yhat2 `event' if `event' >= d(14apr2020) & `event' <= d(15apr2020) `condition3', sort lcolor("106 106 255*0.4") mcolor("106 106 255") lwidth(`lwidth1')  msize(2))			///
							(line yhat2 `event' if `event' >= d(15apr2020) & `event' <= d(16apr2020) `condition3', sort lcolor("106 106 255*0.4") mcolor("106 106 255") lwidth(`lwidth1')  msize(2))			///
							(line yhat2 `event' if `event' >= d(16apr2020) & `event' <= d(17apr2020) `condition3', sort lcolor("106 106 255*0.35") mcolor("106 106 255") lwidth(`lwidth1')  msize(2))			///
							(line yhat2 `event' if `event' >= d(17apr2020) & `event' <= d(18apr2020) `condition3', sort lcolor("106 106 255*0.35") mcolor("106 106 255") lwidth(`lwidth1')  msize(2))			///
							(line yhat2 `event' if `event' >= d(18apr2020) & `event' <= d(19apr2020) `condition3', sort lcolor("106 106 255*0.3") mcolor("106 106 255") lwidth(`lwidth1')  msize(2))			///						
							(rarea yhat_ll2 yhat_ul2 `event' if `event' <= d(02apr2020) `condition3', sort fcolor("106 106 255%30") lcolor("106 106 255%3"))													///
							(rarea yhat_ll2 yhat_ul2 `event' if `event' >= d(02apr2020) & `event' <= d(03apr2020) `condition3', sort fcolor("106 106 255%30") lcolor("106 106 255%3"))							///
							(rarea yhat_ll2 yhat_ul2 `event' if `event' >= d(03apr2020) & `event' <= d(04apr2020) `condition3', sort fcolor("106 106 255%29") lcolor("106 106 255%3"))							///
							(rarea yhat_ll2 yhat_ul2 `event' if `event' >= d(04apr2020) & `event' <= d(05apr2020) `condition3', sort fcolor("106 106 255%28") lcolor("106 106 255%3"))							///
							(rarea yhat_ll2 yhat_ul2 `event' if `event' >= d(05apr2020) & `event' <= d(06apr2020) `condition3', sort fcolor("106 106 255%27") lcolor("106 106 255%3"))							///
							(rarea yhat_ll2 yhat_ul2 `event' if `event' >= d(06apr2020) & `event' <= d(07apr2020) `condition3', sort fcolor("106 106 255%26") lcolor("106 106 255%3"))							///
							(rarea yhat_ll2 yhat_ul2 `event' if `event' >= d(07apr2020) & `event' <= d(08apr2020) `condition3', sort fcolor("106 106 255%25") lcolor("106 106 255%3"))							///
							(rarea yhat_ll2 yhat_ul2 `event' if `event' >= d(08apr2020) & `event' <= d(09apr2020) `condition3', sort fcolor("106 106 255%24") lcolor("106 106 255%3"))							///
							(rarea yhat_ll2 yhat_ul2 `event' if `event' >= d(09apr2020) & `event' <= d(10apr2020) `condition3', sort fcolor("106 106 255%23") lcolor("106 106 255%3"))							///
							(rarea yhat_ll2 yhat_ul2 `event' if `event' >= d(10apr2020) & `event' <= d(11apr2020) `condition3', sort fcolor("106 106 255%22") lcolor("106 106 255%3"))							///
							(rarea yhat_ll2 yhat_ul2 `event' if `event' >= d(11apr2020) & `event' <= d(12apr2020) `condition3', sort fcolor("106 106 255%21") lcolor("106 106 255%3"))							///
							(rarea yhat_ll2 yhat_ul2 `event' if `event' >= d(12apr2020) & `event' <= d(13apr2020) `condition3', sort fcolor("106 106 255%20") lcolor("106 106 255%3"))							///
							(rarea yhat_ll2 yhat_ul2 `event' if `event' >= d(13apr2020) & `event' <= d(14apr2020) `condition3', sort fcolor("106 106 255%19") lcolor("106 106 255%3"))							///
							(rarea yhat_ll2 yhat_ul2 `event' if `event' >= d(14apr2020) & `event' <= d(15apr2020) `condition3', sort fcolor("106 106 255%18") lcolor("106 106 255%3"))							///
							(rarea yhat_ll2 yhat_ul2 `event' if `event' >= d(15apr2020) & `event' <= d(16apr2020) `condition3', sort fcolor("106 106 255%17") lcolor("106 106 255%3"))							///
							(rarea yhat_ll2 yhat_ul2 `event' if `event' >= d(16apr2020) & `event' <= d(17apr2020) `condition3', sort fcolor("106 106 255%16") lcolor("106 106 255%3"))							///
							(rarea yhat_ll2 yhat_ul2 `event' if `event' >= d(17apr2020) & `event' <= d(18apr2020) `condition3', sort fcolor("106 106 255%15") lcolor("106 106 255%3"))							///
							(rarea yhat_ll2 yhat_ul2 `event' if `event' >= d(18apr2020) & `event' <= d(19apr2020) `condition3', sort fcolor("106 106 255%14") lcolor("106 106 255%3")),							///
							graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white) margin(0 5 0 2))																								///	
							xtitle("Date", size(large))																																							///
							ytitle("`ytitilegraph1'", size(large))																																				///
							legend(order(2 "With social" "distancing policies" 4 "Without social" "distancing policies") nobox region(fcolor(none) lcolor(none)))												///							
							ylabel(`ylabel1', grid glcolor(gs15) glpattern(dash))																																///
							tlabel(`tlabel1', angle(340) format(%dd_M)) 																																		///
							tline(12mar2020 16mar2020 23mar2020, lcolor(gray) lpattern(dash))																													///
							text(`text' "Counterfactual based" "on {&le} 1 observations" "per district", size(2.4))																								///
							caption("March 12: Distancing appeal" "March 16: School closure" "March 23: Contact ban", position(11) ring(0) margin(ebargraph) 													///
							box fcolor(white) lcolor(black) bmargin(medlarge) lwidth(vvthin) justification(left) size(medlarge))																				///
							name(graph1b, replace) xsize(17) ysize(15) yscale(`yscale1')
																		
						if `nosave' == 0 {
							graph export "`graphpath'/`graphname1'_shade.png", replace
						}			
			restore
		
		**** graph: sd treatment effect on national level as well as factual on national level
			
			*** create data set with betas that can be merged
				preserve 
					sum `event'
					local evenmin = r(min)
					clear
					svmat b
					svmat ll
					svmat ul
					replace ll = 0 if ll == .
					replace ul = 0 if ul == .
					gen `event' = `evenmin' in 1
					replace `event' = `event'[_n-1] + 1 if `event'[_n-1] != .
					format `event' %d
					tempfile file1 
					save `file1'
				restore
			
			*** merge data set
				cap drop _merge
				merge n:1 `event' using `file1'				
			
			*** transform values into unis (by applying re-transformation)
				gen IHSyhat     = (1 / (2 * `theta')) * (exp(`theta' * yhat) - exp(-`theta' * yhat))
				gen IHSyhat2    = (1 / (2 * `theta')) * (exp(`theta' * yhat2) - exp(-`theta' * yhat2))
				gen IHSyhat2_ll = (1 / (2 * `theta')) * (exp(`theta' * (yhat+(-ll))) - exp(-`theta' * (yhat+(-ll))))
				gen IHSyhat2_ul = (1 / (2 * `theta')) * (exp(`theta' * (yhat+(-ul))) - exp(-`theta' * (yhat+(-ul))))			
	
			*** calculate treatment effects
				gen TE = IHSyhat2 - IHSyhat
				gen TE_ll = IHSyhat2_ll - IHSyhat
				gen TE_ul = IHSyhat2_ul - IHSyhat 
			
			*** locals for graph labels
				if "`outcome'" == "IHSSumCases" {
					local outcome2 "SumCases"
					local label2 "cases"
				}
				if "`outcome'" == "IHSSumDeaths" {
					local outcome2 "SumDeaths"
					local label2 "deaths"
				}		
			
			*** graph: sd effect national level (until: 2.4)		
				preserve 
					*** summ effects on national level
						collapse (sum) TE TE_ll TE_ul `outcome2', by(`event')				
					
					*** values: 19 Apr.
						sum `event'
						sum TE if `event' == r(max)
						local TE = round(r(mean))
						sum `event'
						sum TE_ll  if `event' == r(max)
						local TE_ll = r(mean)
						sum `event'
						sum TE_ul  if `event' == r(max)
						local TE_ul = r(mean)					
											
						scalar TE    = `TE'
						scalar TE_ll = `TE_ll'		
						scalar TE_ul = `TE_ul'						
						
					*** values: 2 Apr.
						sum TE if `event' == d(02Apr2020)
						local TE2 = round(r(mean))
						sum TE_ll  if `event' == d(02Apr2020)
						local TE2_ll = r(mean)
						sum TE_ul  if `event' == d(02Apr2020)
						local TE2_ul = r(mean)						
						
						scalar TE2    = `TE2'
						scalar TE2_ll = `TE2_ll'		
						scalar TE2_ul = `TE2_ul'	
				
					*** print results with confidence intervals
						di in red "----------------------------"
						di in red "Social distancing effect, last period: `TE'"
						di in red "Social distancing lower CI, last period: `TE_ll'"
						di in red "Social distancing upper CI, last period: `TE_ul'"
						di in red ""
						di in red "Social distancing effect, Apr. 2: `TE2'"
						di in red "Social distancing lower CI, Apr. 2: `TE2_ll'"
						di in red "Social distancing upper CI, Apr. 2: `TE2_ul'"					
						di in red "----------------------------"							
					
					*** round values so that they are printed nicely in graph
						if "`outcome'" == "IHSSumCases" {
							local TE = round(`TE'/1000000, 0.1)
							local TE = string(`TE')+"M"				
							local ylabel1 = "0(5000)15400"
						}
						if "`outcome'" == "IHSSumDeaths" {
							local TE = round(`TE'/1000, 0.1)				
							local TE = "`TE'K"		
							local ylabel1 = ""										
						}		
						local TE2 = round(`TE2'/1000, 0.1)				
						local TE2 = "`TE2'K"		
						local ylabel1 = ""										
										
					*** present values in k
						replace TE = TE / 1000
						replace TE_ll = TE_ll / 1000
						replace TE_ul = TE_ul / 1000
						replace `outcome2' = `outcome2' / 1000
							
					*** additional value for graph
						sum `outcome2' if `event' == d(02apr2020)
						local base = round(r(sum), 0.1)
						local base = "`base'K"		
												
					*** graph				
						twoway		(line TE `event' if `event' < d(03apr2020) `condition3', sort lcolor(red) mcolor(red) lwidth(`lwidth1')  msize(2))																			///
									(rarea TE_ll TE_ul `event' if `event' < d(03apr2020) `condition3', sort fcolor(red%30) lcolor(red%3)),																						///
									graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white) margin(0 5 0 2))																										///	
									xtitle("Date", size(large)) 																																								///
									ytitle("`ytitilegraph2'", size(large))	legend(off)																																			///
									ylabel(`ylabel1', grid glcolor(gs15) glpattern(dash))																																		///
									tlabel(`tlabel2', angle(340) format(%dd_M)) 																																				///
									tline(12mar2020 16mar2020 23mar2020, lcolor(gray) lpattern(dash))																															///
									caption("March 12: Distancing appeal" "March 16: School closure" "March 23: Contact ban" " " "Avoided `label2' on April 2:" " Germany: `TE2'", position(11) ring(0) margin(ebargraph) 		///								
									box fcolor(white) lcolor(black) bmargin(medlarge) lwidth(vvthin) justification(left) size(medlarge))																						///
									name(graph2a, replace) xsize(17) ysize(15)								
							
							if `nosave' == 0 {
								graph export "`graphpath'/`graphname2'_short.png", replace
							}		
				restore
			
		*** graph: sd treatment effect on district level
			preserve 
				*** collapse data 
					collapse (mean) yhat yhat2 yhat_ll yhat_ul yhat_ll2 yhat_ul2 `outcome', by(`event')	
					
				*** get estimators
					svmat b
					svmat ll
					svmat ul
					replace ll = 0 if ll == .
					replace ul = 0 if ul == .

				*** transform values into unis (by applying re-transformation)
					gen IHSyhat     = (1 / (2 * `theta')) * (exp(`theta' * yhat) - exp(-`theta' * yhat))
					gen IHSyhat2    = (1 / (2 * `theta')) * (exp(`theta' * yhat2) - exp(-`theta' * yhat2))
					gen IHSyhat2_ll = (1 / (2 * `theta')) * (exp(`theta' * (yhat+(-ll))) - exp(-`theta' * (yhat+(-ll))))
					gen IHSyhat2_ul = (1 / (2 * `theta')) * (exp(`theta' * (yhat+(-ul))) - exp(-`theta' * (yhat+(-ul))))
								 
				*** calculate treatment effects
					gen TE = IHSyhat - IHSyhat2
					gen TE_ll = IHSyhat - IHSyhat2_ll
					gen TE_ul = IHSyhat - IHSyhat2_ul					
									
				*** graph: treatment effect (until 2 April)					
					
					*** further values for graph
					sum `event'
					sum TE if `event' == d(02apr2020)
					local TEDis = -round(r(mean), 0.1)
					local TEDis = string(`TEDis')		
					
					*** graph
					twoway		(line TE `event' if `event' < d(03apr2020) `condition3', sort lcolor(red) mcolor(red) lwidth(`lwidth1')  msize(2))																								///		
								(rarea TE_ll TE_ul `event' if `event'< d(03apr2020) `condition3', sort fcolor("red%30") lcolor("red%3")),																										///
								graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white) margin(0 5 0 2))																															///	
								xtitle("Date", size(large)) 																																													///
								ytitle("`ytitilegraph4'", size(large))																																											///
								ylabel(, grid glcolor(gs15) glpattern(dash))																																									///
								tlabel(`tlabel2', angle(340) format(%dd_M)) 																																									///
								tline(12mar2020 16mar2020 23mar2020, lcolor(gray) lpattern(dash))																																				///
								caption("March 12: Distancing appeal" "March 16: School closure" "March 23: Contact ban" " " "Avoided `label2' on April 2:" " District:  `TEDis'" " Germany: `TE2'", position(7) ring(0) margin(ebargraph) 		///	
								box fcolor(white) lcolor(black) bmargin(medlarge) lwidth(vvthin) justification(left) size(medlarge))																											///
								name(graph4b, replace) xsize(17) ysize(15)																																										///
								legen(order(1 "Social distancing" "effect") nobox region(fcolor(none) lcolor(none)))	
		
					if `nosave' == 0 {
						graph export "`graphpath'/`graphname4'_short.png", replace
					}								
			}
end